@@ -1,8 +1,6 @@
-/*
- * Drop constraints managed by pg_partman
- */
 CREATE FUNCTION @extschema@.drop_constraints(p_parent_table text, p_child_table text, p_debug boolean DEFAULT false) RETURNS void
     LANGUAGE plpgsql
+    SET search_path = @extschema@, pg_catalog, pg_temp
     AS $$
 DECLARE
 
@@ -25,6 +23,9 @@ v_sql                           text;
 v_step_id                       bigint;
 
 BEGIN
+/*
+ * Drop constraints managed by pg_partman
+ */
 
 SELECT constraint_cols
     , jobmon
@@ -38,16 +39,13 @@ IF v_constraint_cols IS NULL THEN
 END IF;
 
 IF v_jobmon THEN
-    SELECT nspname INTO v_jobmon_schema FROM pg_catalog.pg_namespace n, pg_catalog.pg_extension e WHERE e.extname = 'pg_jobmon' AND e.extnamespace = n.oid;
+    SELECT nspname INTO v_jobmon_schema FROM pg_catalog.pg_namespace n, pg_catalog.pg_extension e WHERE e.extname = 'pg_jobmon'::name AND e.extnamespace = n.oid;
     IF v_jobmon_schema IS NOT NULL THEN
         SELECT current_setting('search_path') INTO v_old_search_path;
-        IF length(v_old_search_path) > 0 THEN
-           v_new_search_path := '@extschema@,pg_temp,'||v_old_search_path;
-        ELSE
-            v_new_search_path := '@extschema@,pg_temp';
+        IF v_jobmon_schema IS NOT NULL THEN
+            v_new_search_path := format('%s,%s',v_jobmon_schema, v_old_search_path);
+            EXECUTE format('SET LOCAL search_path TO %s', v_new_search_path);
         END IF;
-        v_new_search_path := format('%s,%s',v_jobmon_schema, v_new_search_path);
-        EXECUTE format('SELECT set_config(%L, %L, %L)', 'search_path', v_new_search_path, 'false');
     END IF;
 END IF;
 
@@ -106,7 +104,6 @@ END IF;
 
 IF v_jobmon_schema IS NOT NULL THEN
     PERFORM close_job(v_job_id);
-    EXECUTE format('SELECT set_config(%L, %L, %L)', 'search_path', v_old_search_path, 'false');
 END IF;
 
 EXCEPTION
